/*
 * Copyright (c) 2018-2019. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.img.fs;

import java.io.IOException;
import java.net.URI;

/**
 * FileSystem Detector.
 *
 * @author Dmitry Samoshin aka gotty
 */
public final class FileSystemDetector {

    private static final String JAR_SCHEME_NAME = "jar";

    public static FileSystemContractor detect(URI uri) throws IOException {
        if (JAR_SCHEME_NAME.equals(uri.getScheme())) {
            return new JarFileSystemContractor(uri);
        } else {
            return new DefFileSystemContractor(uri);
        }
    }

    public static boolean detectJar(URI uri) {
        return JAR_SCHEME_NAME.equals(uri.getScheme());
    }

}
