/*
 * Copyright (c) 2018-2019. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.qrcode;

import java.util.ResourceBundle;

import org.hedgecode.chess.ChessQRCodeConstants;

/**
 * Chess-specific QR Codes read/write/parse Exception.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class ChessQRCodeException extends Exception {

    public enum Type {

        READ  ("[Read Error] "),
        WRITE ("[Write Error] "),
        PARSE ("[Parse Error] ");

        private String msg;

        Type(String msg) {
            this.msg = msg;
        }
    }

    private static final ResourceBundle LOCALE_BUNDLE =
            ResourceBundle.getBundle(ChessQRCodeConstants.LOCALE_BUNDLE_FILE);

    private Type type;
    private String localeKey;
    private String message;

    public ChessQRCodeException(Type type, String localeKey) {
        this.type = type;
        this.localeKey = localeKey;
        this.message = null;
    }

    public ChessQRCodeException(Type type, String localeKey, String message) {
        this.type = type;
        this.localeKey = localeKey;
        this.message = message;
    }

    public Type getType() {
        return type;
    }

    public String getLocaleKey() {
        return localeKey;
    }

    public String getMessage() {
        StringBuilder sb = new StringBuilder();
        sb.append(type.msg);
        if (localeKey != null)
            sb.append(
                    LOCALE_BUNDLE.getString(localeKey)
            );
        if (message != null)
            sb.append(": ").append(message);
        return sb.toString();
    }

}
